Class: Object
- Inherits:
- BasicObject
- Defined in:
- lib/rui/utils.rb
Overview
Copyright (c) 2009-2010 Paolo Capriotti [email protected]
This library is free software; you can redistribute it and/or modify it under the terms of the GNU Lesser General Public License as published by the Free Software Foundation; either version 3 of the License, or (at your option) any later version.